searchData={"items":[{"type":"module","title":"Pbkdf2","doc":"Elixir wrapper for the Pbkdf2 password hashing function.\n\nFor a lower-level API, see `Pbkdf2.Base`.","ref":"Pbkdf2.html"},{"type":"module","title":"Configuration - Pbkdf2","doc":"The following parameter can be set in the config file:\n\n  * `:rounds` - computational cost\n    * the number of rounds\n    * `160_000` is the default\n\nIf you are hashing passwords in your tests, it can be useful to add\nthe following to the `config/test.exs` file:\n\n    # Note: Do not use this value in production\n    config :pbkdf2_elixir,\n      rounds: 1","ref":"Pbkdf2.html#module-configuration"},{"type":"module","title":"Pbkdf2 - Pbkdf2","doc":"Pbkdf2 is a password-based key derivation function\nthat uses a password, a variable-length salt and an iteration\ncount and applies a pseudorandom function to these to\nproduce a key.\n\nThe original implementation used SHA-1 as the pseudorandom function,\nbut this version uses HMAC-SHA-512, the default, or HMAC-SHA-256.","ref":"Pbkdf2.html#module-pbkdf2"},{"type":"module","title":"Warning - Pbkdf2","doc":"It is recommended that you set a maximum length for the password\nwhen using Pbkdf2. This maximum length should not prevent valid users from setting\nlong passwords. It is instead needed to combat denial-of-service attacks.\nAs an example, Django sets the maximum length to `4096` bytes.\nFor more information, see [this link](https://www.djangoproject.com/weblog/2013/sep/15/security/).","ref":"Pbkdf2.html#module-warning"},{"type":"function","title":"Pbkdf2.hash_pwd_salt/2","doc":"Hashes a password with a randomly generated salt.","ref":"Pbkdf2.html#hash_pwd_salt/2"},{"type":"function","title":"Options - Pbkdf2.hash_pwd_salt/2","doc":"In addition to the options for `Pbkdf2.Base.gen_salt/1` (`:salt_len` and\n`:format`), this function also takes options that are then passed on to\nthe `hash_password` function in the `Pbkdf2.Base` module.\n\nSee the documentation for `Pbkdf2.Base.hash_password/3` for further details.","ref":"Pbkdf2.html#hash_pwd_salt/2-options"},{"type":"function","title":"Examples - Pbkdf2.hash_pwd_salt/2","doc":"The following examples show how to hash a password with a randomly-generated\nsalt and then verify a password:\n\n    iex> hash = Pbkdf2.hash_pwd_salt(\"password\")\n    ...> Pbkdf2.verify_pass(\"password\", hash)\n    true\n\n    iex> hash = Pbkdf2.hash_pwd_salt(\"password\")\n    ...> Pbkdf2.verify_pass(\"incorrect\", hash)\n    false\n\nThe next examples show how to use some of the various available options:\n\n    iex> hash = Pbkdf2.hash_pwd_salt(\"password\", rounds: 100_000)\n    ...> Pbkdf2.verify_pass(\"password\", hash)\n    true\n\n    iex> hash = Pbkdf2.hash_pwd_salt(\"password\", digest: :sha256)\n    ...> Pbkdf2.verify_pass(\"password\", hash)\n    true\n\n    iex> hash = Pbkdf2.hash_pwd_salt(\"password\", digest: :sha256, format: :django)\n    ...> Pbkdf2.verify_pass(\"password\", hash)\n    true","ref":"Pbkdf2.html#hash_pwd_salt/2-examples"},{"type":"function","title":"Pbkdf2.no_user_verify/1","doc":"Runs the password hash function, but always returns false.\n\nThis function is intended to make it more difficult for any potential\nattacker to find valid usernames by using timing attacks. This function\nis only useful if it is used as part of a policy of hiding usernames.","ref":"Pbkdf2.html#no_user_verify/1"},{"type":"function","title":"Options - Pbkdf2.no_user_verify/1","doc":"This function should be called with the same options as those used by\n`hash_pwd_salt/2`.","ref":"Pbkdf2.html#no_user_verify/1-options"},{"type":"function","title":"Hiding usernames - Pbkdf2.no_user_verify/1","doc":"In addition to keeping passwords secret, hiding the precise username\ncan help make online attacks more difficult. An attacker would then\nhave to guess a username / password combination, rather than just\na password, to gain access.\n\nThis does not mean that the username should be kept completely secret.\nAdding a short numerical suffix to a user's name, for example, would be\nsufficient to increase the attacker's work considerably.\n\nIf you are implementing a policy of hiding usernames, it is important\nto make sure that the username is not revealed by any other part of\nyour application.","ref":"Pbkdf2.html#no_user_verify/1-hiding-usernames"},{"type":"function","title":"Pbkdf2.verify_pass/2","doc":"Verifies a password by hashing the password and comparing the hashed value\nwith a stored hash.\n\nSee the documentation for `hash_pwd_salt/2` for examples of using this function.","ref":"Pbkdf2.html#verify_pass/2"},{"type":"module","title":"Pbkdf2.Base","doc":"Base module for the Pbkdf2 password hashing library.","ref":"Pbkdf2.Base.html"},{"type":"function","title":"Pbkdf2.Base.gen_salt/1","doc":"Generates a random salt.\n\nThis function takes one optional argument - a keyword list (see below\nfor more details).","ref":"Pbkdf2.Base.html#gen_salt/1"},{"type":"function","title":"Options - Pbkdf2.Base.gen_salt/1","doc":"The following options are available:\n\n  * `:salt_len` - the length of the random salt\n    * the default is 16 bytes\n    * for more information, see the 'Salt length recommendations' section below\n  * `:format` - the length of the random salt\n    * the default is `:modular` (modular crypt format)\n    * the other available options are `:django` and `:hex`","ref":"Pbkdf2.Base.html#gen_salt/1-options"},{"type":"function","title":"Examples - Pbkdf2.Base.gen_salt/1","doc":"Here is an example of generating a salt with the default salt length and format:\n\n    Pbkdf2.Base.gen_salt()\n\nTo generate a different length salt:\n\n    Pbkdf2.Base.gen_salt(salt_len: 32)\n\nAnd to generate a salt in Django output format:\n\n    Pbkdf2.Base.gen_salt(format: :django)","ref":"Pbkdf2.Base.html#gen_salt/1-examples"},{"type":"function","title":"Salt length recommendations - Pbkdf2.Base.gen_salt/1","doc":"In most cases, 16 bytes is a suitable length for the salt.\nIt is not recommended to use a salt that is shorter than this\n(see below for details and references).\n\nAccording to the [Pbkdf2 standard](https://tools.ietf.org/html/rfc8018),\nthe salt should be at least 8 bytes long, but according to [NIST\nrecommendations](https://nvlpubs.nist.gov/nistpubs/Legacy/SP/nistspecialpublication800-132.pdf),\nthe minimum salt length should be 16 bytes.","ref":"Pbkdf2.Base.html#gen_salt/1-salt-length-recommendations"},{"type":"function","title":"Pbkdf2.Base.hash_password/3","doc":"Hash a password using Pbkdf2.","ref":"Pbkdf2.Base.html#hash_password/3"},{"type":"function","title":"Options - Pbkdf2.Base.hash_password/3","doc":"There are four options (`rounds` can be used to override the value\nin the config):\n\n  * `:rounds` - the number of rounds\n    * the amount of computation, given in number of iterations\n    * the default is 160_000\n    * this can also be set in the config file\n  * `:format` - the output format of the hash\n    * the default is `:modular` - modular crypt format\n    * the other available formats are:\n      * `:django` - the format used in django applications\n      * `:hex` - the hash is encoded in hexadecimal\n  * `:digest` - the sha algorithm that pbkdf2 will use\n    * the default is sha512\n  * `:length` - the length, in bytes, of the hash\n    * the default is 64 for sha512 and 32 for sha256","ref":"Pbkdf2.Base.html#hash_password/3-options"},{"type":"function","title":"Pbkdf2.Base.verify_pass/6","doc":"Verify a password by comparing it with the stored Pbkdf2 hash.","ref":"Pbkdf2.Base.html#verify_pass/6"},{"type":"module","title":"Pbkdf2.Base64","doc":"Module that provides base64 encoding for Pbkdf2.\n\nMost developers will not need to use this module directly.\n\nPbkdf2 uses an adapted base64 alphabet (using `.` instead of `+`\nand with no padding).","ref":"Pbkdf2.Base64.html"},{"type":"function","title":"Pbkdf2.Base64.decode/1","doc":"Decode using the adapted Pbkdf2 alphabet.","ref":"Pbkdf2.Base64.html#decode/1"},{"type":"function","title":"Examples - Pbkdf2.Base64.decode/1","doc":"iex> Pbkdf2.Base64.decode(\"c3BhbWFuZGVnZ3M\")\n    \"spamandeggs\"","ref":"Pbkdf2.Base64.html#decode/1-examples"},{"type":"function","title":"Pbkdf2.Base64.encode/1","doc":"Encode using the adapted Pbkdf2 alphabet.","ref":"Pbkdf2.Base64.html#encode/1"},{"type":"function","title":"Examples - Pbkdf2.Base64.encode/1","doc":"iex> Pbkdf2.Base64.encode(\"spamandeggs\")\n    \"c3BhbWFuZGVnZ3M\"","ref":"Pbkdf2.Base64.html#encode/1-examples"},{"type":"module","title":"Pbkdf2.Stats","doc":"Module to provide statistics for the Pbkdf2 password hashing function.","ref":"Pbkdf2.Stats.html"},{"type":"module","title":"Configuring Pbkdf2 - Pbkdf2.Stats","doc":"The main configuration option for Pbkdf2 is the number of rounds that\nit uses. Increasing this value will increase the complexity, and time\ntaken, of the Pbkdf2 function.\n\nIncreasing the time that a password hash function takes makes it more\ndifficult for an attacker to find the correct password. However, the\namount of time a valid user has to wait also needs to be taken into\nconsideration when setting the number of rounds.\n\nThe correct number of rounds depends on circumstances specific to your\nuse case, such as what level of security you want, how often the user\nhas to log in, and the hardware you are using. However, for password\nhashing, we do not recommend setting the number of rounds to anything\nless than 100_000.","ref":"Pbkdf2.Stats.html#module-configuring-pbkdf2"},{"type":"function","title":"Pbkdf2.Stats.report/1","doc":"Hash a password with Pbkdf2 and print out a report.\n\nThis function hashes a password, and salt, with Pbkdf2.Base.hash_password/3\nand prints out statistics which can help you choose how to configure Pbkdf2.","ref":"Pbkdf2.Stats.html#report/1"},{"type":"function","title":"Options - Pbkdf2.Stats.report/1","doc":"In addition to the options for Pbkdf2.Base.hash_password (rounds, output_fmt,\ndigest and length), there are two options:\n\n  * `:password` - the password used\n    * the default is \"password\"\n  * `:salt` - the salt used\n    * the default is \"somesaltSOMESALT\"","ref":"Pbkdf2.Stats.html#report/1-options"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v2.2.0 - 2023-08-26 - Changelog","doc":"* Changes\n  * Updated dependencies and documentation (through updates to the Comeonin documentation)","ref":"changelog.html#v2-2-0-2023-08-26"},{"type":"extras","title":"v2.0.0 - 2022-01-20 - Changelog","doc":"* Changes\n  * updated `gen_salt` and moved it to the `Base` module","ref":"changelog.html#v2-0-0-2022-01-20"},{"type":"extras","title":"v1.4.1 - 2022-01-19 - Changelog","doc":"* Changes\n  * updated documentation and README","ref":"changelog.html#v1-4-1-2022-01-19"},{"type":"extras","title":"v1.4.0 - 2021-04-08 - Changelog","doc":"* Changes\n  * updated hmac sha function to support the new crypto api in OTP 24","ref":"changelog.html#v1-4-0-2021-04-08"},{"type":"extras","title":"v1.3.0 - 2021-01-08 - Changelog","doc":"* Bug fixes\n  * made sure that `hash_pwd_salt/2` passes the `format: :django` option onto `gen_salt/1`\n* Changes\n  * changed minimum salt length to 0 bytes and added warning for salts between 0 and 8 bytes long\n  * updated documentation about salt length with more information about the minimum recommended value\n  * updated `gen_salt/1` to take a keyword list by default (an integer is also allowed for backwards compatibility)\n* Deprecations\n  * `Base.django_salt/1` has been deprecated - `gen_salt/1` can be used instead","ref":"changelog.html#v1-3-0-2021-01-08"},{"type":"extras","title":"v1.2.0 - 2020-03-01 - Changelog","doc":"* Changes\n  * using Comeonin v5.3, which changes `add_hash/2` so that it does NOT set the password to nil","ref":"changelog.html#v1-2-0-2020-03-01"},{"type":"extras","title":"v1.1.0 - 2020-01-20 - Changelog","doc":"* Enhancements\n  * Updated documentation - in line with updates to Comeonin v5.2","ref":"changelog.html#v1-1-0-2020-01-20"},{"type":"extras","title":"v1.0.0 - 2019-02-19 - Changelog","doc":"* Enhancements\n  * Updated to use Comeonin behaviour","ref":"changelog.html#v1-0-0-2019-02-19"},{"type":"extras","title":"v0.12.0 - 2017-07-21 - Changelog","doc":"* Changes\n  * Created separate Pbkdf2 library","ref":"changelog.html#v0-12-0-2017-07-21"},{"type":"extras","title":"License","doc":"All code in this application, unless otherwise stated, is subject\nto the following license:\n\nCopyright (c) 2014-2021 David Whitlock (alovedalongthe@gmail.com)\n\nSome rights reserved.\nRedistribution and use in source and binary forms of the software as well\nas documentation, with or without modification, are permitted provided\nthat the following conditions are met:\n\n* Redistributions of source code must retain the above copyright\nnotice, this list of conditions and the following disclaimer.\n* Redistributions in binary form must reproduce the above\ncopyright notice, this list of conditions and the following\ndisclaimer in the documentation and/or other materials provided\nwith the distribution.\n* The names of the contributors may not be used to endorse or\npromote products derived from this software without specific\nprior written permission.\n\nTHIS SOFTWARE AND DOCUMENTATION IS PROVIDED BY THE COPYRIGHT HOLDERS AND\nCONTRIBUTORS \"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT\nNOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\nA PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER\nOR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\nEXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\nPROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR\nPROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF\nLIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\nNEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\nSOFTWARE AND DOCUMENTATION, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH\nDAMAGE.","ref":"license.html"},{"type":"extras","title":"Pbkdf2","doc":"# Pbkdf2\n\n[![Build Status](https://travis-ci.com/riverrun/pbkdf2_elixir.svg?branch=master)](https://travis-ci.com/riverrun/pbkdf2_elixir)\n[![Module Version](https://img.shields.io/hexpm/v/pbkdf2_elixir.svg)](https://hex.pm/packages/pbkdf2_elixir)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/pbkdf2_elixir/)\n[![Total Download](https://img.shields.io/hexpm/dt/pbkdf2_elixir.svg)](https://hex.pm/packages/pbkdf2_elixir)\n[![License](https://img.shields.io/hexpm/l/pbkdf2_elixir.svg)](https://github.com/riverrun/pbkdf2_elixir/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/riverrun/pbkdf2_elixir.svg)](https://github.com/riverrun/pbkdf2_elixir/commits/master)\n[![Join the chat at https://gitter.im/comeonin/Lobby](https://badges.gitter.im/comeonin/Lobby.svg)](https://gitter.im/comeonin/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)\n\nPbkdf2 password hashing library for Elixir.\n\nPbkdf2 is a well-tested password-based key derivation function that can be\nconfigured to remain slow and resistant to brute-force attacks even as\ncomputational power increases.","ref":"readme.html"},{"type":"extras","title":"Comparison with the Plug.Crypto version of Pbkdf2 - Pbkdf2","doc":"If you want the Pbkdf2 output to be in binary (raw) or hex format, you might\nfind [Plug.Crypto.KeyGenerator](https://hexdocs.pm/plug_crypto/Plug.Crypto.KeyGenerator.html)\nmore convenient.","ref":"readme.html#comparison-with-the-plug-crypto-version-of-pbkdf2"},{"type":"extras","title":"Installation - Pbkdf2","doc":"1.  Add `:pbkdf2_elixir` to the `deps` section of your `mix.exs` file:\n\n    ```elixir\n    def deps do\n      [\n        {:pbkdf2_elixir, \"~> 2.0\"}\n      ]\n    end\n    ```\n\n2.  Optional: during tests (and tests only), you may want to reduce the number of rounds\nso it does not slow down your test suite. If you have a `config/test.exs`, you should\nadd:\n\n    ```elixir\n    config :pbkdf2_elixir, :rounds, 1\n    ```","ref":"readme.html#installation"},{"type":"extras","title":"Comeonin wiki - Pbkdf2","doc":"See the [Comeonin wiki](https://github.com/riverrun/comeonin/wiki) for more\ninformation on the following topics:\n\n* [Algorithms](https://github.com/riverrun/comeonin/wiki/Choosing-the-password-hashing-algorithm)\n* [Requirements](https://github.com/riverrun/comeonin/wiki/Requirements)\n* [Deployment](https://github.com/riverrun/comeonin/wiki/Deployment)\n  * including information about using Docker\n* [References](https://github.com/riverrun/comeonin/wiki/References)","ref":"readme.html#comeonin-wiki"},{"type":"extras","title":"Contributing - Pbkdf2","doc":"There are many ways you can contribute to the development of this library, including:\n\n* Reporting issues\n* Improving documentation\n* Sharing your experiences with others","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - Pbkdf2","doc":"Copyright (c) 2014-2021 David Whitlock (alovedalongthe@gmail.com)\n\nThis software is licensed under [the BSD-3-Clause license](./LICENSE.md).","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}